<?php

/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       https://www.getfoundni.co.uk/
 * @since      1.0.0
 *
 * @package    Notify_Gfni
 * @subpackage Notify_Gfni/admin/partials
 */

$notify_settings_options = get_option('notify_settings_option_name');
$key_0 = $notify_settings_options['key_0'];
$from_email_1 = $notify_settings_options['from_email_1'];
$from_name_2 = $notify_settings_options['from_name_2'];
$image = wp_get_attachment_image_src($notify_settings_options['from_name_3']);

if (!$key_0) {
    header("Location: /wp-admin/admin.php?page=notify-plugin-options&key=404");
}
?>

 <div class="sublist">
	<h1>Your Subscriber List</h1>

	<table id="sublist" class="ui celled table">
		<thead>
			<tr>
				<th>ID</th>
				<th>First Name</th>
				<th>Last Name</th>
				<th>Email</th>
				<th>Subscribed</th>
				<th>Tester</th>
				<th>Remove</th>
			</tr>
		</thead>
		<tfoot>
			<tr>
				<th>ID</th>
				<th>First Name</th>
				<th>Last Name</th>
				<th>Email</th>
				<th>Subscribed</th>
				<th>Tester</th>
				<th>Remove</th>
			</tr>
		</tfoot>
	</table>

	<form id="notifysubscribe" method="POST" action="https://notify.getfoundni.co.uk/api/subscribe">
		<div class="notify-card">
			<div class="notify-card-title">
				<img src="<?php echo plugin_dir_url(dirname(__FILE__)) ?>assets/logo.png" alt="Notify by Get Found NI">
			</div>
			<div class="notify-card-subtitle">
				<h2>Quick add a subscriber</h2>
			</div>
			<div class="notify-card-body">

				<input type="hidden" name="key" value="<?php echo $key_0; ?>">

				<div class="notify-input">
					<label for="email"> Email Address </label>
					<input name="email" type="email" class="regular-text" placeholder="Email Address" required/>
					<div style="display:none;" class="notice notice-error inline email"></div>
				</div>


				<div class="notify-input">
					<label for="first_name"> First Name <small>(optional)</small></label>
					<input name="first_name" type="text" class="regular-text" placeholder="First Name" />
					<div style="display:none;" class="notice notice-error inline first_name"></div>
				</div>


				<div class="notify-input">
					<label for="last_name"> Last Name <small>(optional)</small></label>
					<input name="last_name" type="text" class="regular-text" placeholder="Last Name" />
					<div style="display:none;" class="notice notice-error inline last_name"></div>
				</div>

				<div  >
					<label for="testing_segment">
					    <input name="testing_segment" type="checkbox"  />Email Testing Segment <small>(optional)</small>
                    </label>
					<div style="display:none;" class="notice notice-error inline testing_segment"></div>
				</div>

				<div style="display:none" id="result" class="notice notice-success notify-success"></div>
			</div>

			<div class="notify-card-footer"><?php submit_button('Subscribe!'); ?></div>

		</div>
	</form>

	<div class="sync">
		<h2>Add All Users To Subscriber List</h2>
		<h4 class="syncingtext"></h4>
		<button class="syncajax button button-primary" type="submit">Sync All Contacts <span style="display:none;" class="nspin fas fa-sync fa-spin"></span></button>
	</div>


</div>

<script>
	(function( $ ) {
		'use strict';

		$( window ).load(function() {
			/**
			 * Sub List Datatabales
			 */
			var dtable = $('#sublist').DataTable({
                "processing": true,
                "serverSide": true,
                "searchDelay": 1100,
				"ajax": "https://notify.getfoundni.co.uk/api/<?php echo $key_0; ?>/subscribers-v2",
				"order": [[0, 'desc']],
				"columns": [
					{ "data": "id", "name": "id" },
					{ "data": "first_name", "name": "first_name"  },
					{ "data": "last_name", "name": "last_name"  },
					{ "data": "email", "name": "email"  },
					{ "data": "unsubscribed_at", "name": "unsubscribed_at"  },
					{ "data": "segments", "name": "segments"  },
					{ "data": "remove", "name": "remove"  }
				]
			} );

			/**
			 * Sync All Contacts
			 */
			$('body').on('click','.syncajax', function(e){
				e.preventDefault();

				var feedback = $('h4.syncingtext');

				$('.nspin').show();
				$('.syncajax').prop('disabled', true);

				var url = "<?php echo admin_url('admin-ajax.php'); ?>";
				var synced = 0;
				var chunk = null;

				feedback.text('Retriving Users & Syncing to notify.... Please Wait & Dont Refresh.');

				$.ajax({
					type: "GET",
					url: url,
					data:{
						action: "notify_sync_contacts",
					},
					headers: {
						'Content-Type': 'application/json',
						'Accept': 'application/json'
					},
				}).done(function(data) {
					chunk = JSON.parse(data);
					chunk.forEach(el => {

						$.ajax({
							type: "POST",
							async: false,
							url: "https://notify.getfoundni.co.uk/api/sync",
							data:{
								key: el.key,
								users: el.users
							},
							headers: {
								'Accept': 'application/json'
							},
						});

						synced = +synced + +el.users.length;

					});
				}).always(function(data) {

						$('.nspin').hide();
						feedback.text('Sync Complete - Total Synced:' + synced);
						$('.syncajax').prop('disabled', false);

				});

			});

			/**
			 * Un-Sub or Re-sub table buttons
			 */
			$('body').on('click','#subchange', function(e){
				e.preventDefault();
				console.log('yoo');
				var field = $(this);
				var id = field.data("id");
				var email = field.data("email");
				var type = field.data("subscribed");

				if(type){
					var url = "https://notify.getfoundni.co.uk/api/unsubscribe";
					var text = "Re-Subscribe" ;
					var icon = "❌";
				} else {
					var url = "https://notify.getfoundni.co.uk/api/resubscribe";
					var text = "Unsubscribe"
					var icon = "✅";
				}

				$.ajax({
					type: "POST",
					url: url,
					data:{
						key: "<?php echo $key_0; ?>",
						email: email,
						id: id
					},
					headers: {
						'Accept': 'application/json'
					},
				}).done(function(data) {
					field.data("subscribed",!type);
					field.html(text);
					$('#sub_' + id).html(icon)
				});


			});

			$("#notifysubscribe").submit(function(event) {

				// Stop form from submitting normally
				event.preventDefault();

				// Get some values from elements on the page:
				var $form = $(this),
					key 		= $form.find("input[name='key']").val(),
					email 		= $form.find("input[name='email']").val(),
					first_name 	= $form.find("input[name='first_name']").val(),
					last_name 	= $form.find("input[name='last_name']").val(),
					testing_segment = $form.find("input[name='testing_segment']").is(':checked'),
					url 		= $form.attr("action");

				var formdata = {
					key:key,
					first_name:first_name,
					last_name:last_name,
					email:email,
                    testing_segment:testing_segment,
				}
                console.log(formdata);

				// Send the data using post
				$.ajax({
					type: "POST",
					url: url,
					data:formdata,
					headers: {
						'Accept': 'application/json'
					},
				}).done(function(data) {
					$(".notice-error").empty().hide();
					$("#result").empty().show().append(data.success);
					$("input[type=text]").val('');
					$("input[type=email]").val('');
					$('#sublist').DataTable().ajax.reload()
				}).fail(function(data) {
					$("#result").empty().hide()
					$(".notice-error").empty().hide();
					$.each(data.responseJSON.errors, function (index, item) {
						$("." + index).empty().show().append(item[0]);
					});
				}).always(function(data) {

				});
			});

		});
	})( jQuery );
</script>
